"use strict";
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getApiConfigFromEnv = exports.formatConfigHostnames = exports.addProtocolToHost = exports.makeKiboAPIHeaders = exports.getKiboHostedConfig = exports.isShopperAuthExpired = exports.normalizeShopperAuthResponse = exports.getHostFromUrl = exports.isValidConfig = exports.getProxyAgent = exports.calculateTicketExpiration = void 0;
const http_proxy_agent_1 = __importDefault(require("http-proxy-agent"));
const https_proxy_agent_1 = __importDefault(require("https-proxy-agent"));
const constants = {
    headerPrefix: "x-vol-",
    headers: {
        APPCLAIMS: "app-claims",
        USERCLAIMS: "user-claims",
        TENANT: "tenant",
        SITE: "site",
        MASTERCATALOG: "master-catalog",
        CATALOG: "catalog",
    },
};
const calculateTicketExpiration = (kiboAuthTicket) => Date.now() + kiboAuthTicket.expires_in * 1000;
exports.calculateTicketExpiration = calculateTicketExpiration;
const getProxyAgent = () => {
    let options = { agent: null };
    if (process.env.HTTPS_PROXY || process.env.HTTP_PROXY) {
        process.env.NODE_TLS_REJECT_UNAUTHORIZED = "0";
        options.agent = process.env.HTTP_PROXY
            ? new http_proxy_agent_1.default.HttpProxyAgent(process.env.HTTP_PROXY)
            : new https_proxy_agent_1.default.HttpsProxyAgent(process.env.HTTPS_PROXY);
    }
    return options;
};
exports.getProxyAgent = getProxyAgent;
const isValidConfig = (config) => {
    const { api: apiConfig } = config || {};
    if (!apiConfig ||
        !(apiConfig.accessTokenUrl || apiConfig.authHost) ||
        !apiConfig.apiHost ||
        !apiConfig.clientId ||
        !apiConfig.sharedSecret)
        return false;
    return true;
};
exports.isValidConfig = isValidConfig;
//naive method to grab auth host from auth url
const getHostFromUrl = (url) => {
    const match = url.match(/^https?\:\/\/([^\/:?#]+)(?:[\/:?#]|$)/i);
    return (match && match[0]) || "";
};
exports.getHostFromUrl = getHostFromUrl;
// normalize anonymous / registered shopper auth ticket
const normalizeShopperAuthResponse = (apiResponse) => {
    const { accessToken, accessTokenExpiration, refreshToken, userId, refreshTokenExpiration, } = apiResponse;
    return {
        accessToken,
        accessTokenExpiration,
        refreshToken,
        userId,
        refreshTokenExpiration,
    };
};
exports.normalizeShopperAuthResponse = normalizeShopperAuthResponse;
const isShopperAuthExpired = (userAuthTicket) => {
    const { accessTokenExpiration } = userAuthTicket;
    return new Date(accessTokenExpiration).getTime() < Date.now();
};
exports.isShopperAuthExpired = isShopperAuthExpired;
const getKiboHostedConfig = () => {
    try {
        return JSON.parse(process.env.mozuHosted).sdkConfig;
    }
    catch (error) {
        throw new Error("Error parsing Kibo Hosted environment variables: " + error.message);
    }
};
exports.getKiboHostedConfig = getKiboHostedConfig;
const makeKiboAPIHeaders = (kiboHostedConfig) => {
    return Object.values(constants.headers).reduce((accum, headerSuffix) => {
        if (!kiboHostedConfig[headerSuffix]) {
            return accum;
        }
        const headerName = `${constants.headerPrefix}${headerSuffix}`;
        accum[headerName] = kiboHostedConfig[headerSuffix];
        return accum;
    }, {});
};
exports.makeKiboAPIHeaders = makeKiboAPIHeaders;
const protocolRegx = new RegExp(/https?:\/\//);
const addProtocolToHost = (hostname) => hostname && !hostname.match(protocolRegx) ? `https://${hostname}` : hostname;
exports.addProtocolToHost = addProtocolToHost;
const formatConfigHostnames = (config) => {
    const { apiHost, authHost } = config, creds = __rest(config, ["apiHost", "authHost"]);
    return Object.assign({ apiHost: exports.addProtocolToHost(apiHost), authHost: exports.addProtocolToHost(authHost) }, creds);
};
exports.formatConfigHostnames = formatConfigHostnames;
const getApiConfigFromEnv = () => ({
    clientId: process.env.KIBO_CLIENT_ID,
    sharedSecret: process.env.KIBO_SHARED_SECRET,
    authHost: process.env.KIBO_AUTH_HOST,
    apiHost: process.env.KIBO_API_HOST,
});
exports.getApiConfigFromEnv = getApiConfigFromEnv;
//# sourceMappingURL=index.js.map